#[repr(transparent)]pub struct ContextMenuBin {
inner: TypedObjectRef<ContextMenuBin, <ContextMenuBin as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A Bin widget that can have a context menu.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<ContextMenuBin, <ContextMenuBin as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl ContextMenuBin
impl ContextMenuBin
Whether this widget has a context menu.
If this is set to false, all the actions will be disabled.
Whether this widget has a context menu.
If this is set to false, all the actions will be disabled.
Sourcepub fn popover(&self) -> <BoundObject<PopoverMenu> as Property>::Value
pub fn popover(&self) -> <BoundObject<PopoverMenu> as Property>::Value
The popover displaying the context menu.
Sourcepub fn set_popover<'a>(
&self,
value: Option<impl Borrow<<<BoundObject<PopoverMenu> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_popover<'a>( &self, value: Option<impl Borrow<<<BoundObject<PopoverMenu> as Property>::Value as HasParamSpec>::SetValue>>, )
The popover displaying the context menu.
Sourcepub fn set_child<'a>(
&self,
value: Option<impl Borrow<<<RefCell<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_child<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>, )
The child widget.
Listen for notifications of a change in the has-context-menu property
Sourcepub fn connect_popover_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_popover_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the popover property
Sourcepub fn connect_child_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the child property
Notify listeners of a change in the has-context-menu property
Sourcepub fn notify_popover(&self)
pub fn notify_popover(&self)
Notify listeners of a change in the popover property
Sourcepub fn notify_child(&self)
pub fn notify_child(&self)
Notify listeners of a change in the child property